"""Language features module

The `__future__` module is used by other Python implementations to
enable forward compatibility for features enabled by default in an upcoming version.
"""

from __future__ import annotations

from typing import Any

annotations: Any
"""In CPython, ``from __future import annotations``
indicates that evaluation of annotations is postponed, as described in PEP 563.
CircuitPython (and MicroPython) ignore annotations entirely, whether or not this feature is imported.
This is a limitation of CircuitPython and MicroPython for efficiency reasons.
"""



from os import listdir, path

from setuptools import setup

__name__ = "types-circuitpython"
__version__ = "8.0.0-alpha.1"
__repo__ = "https://github.com/hardfury-labs/types-circuitpython"
__author__ = "HardFury"


HERE = path.abspath(path.dirname(__file__))
BINDINGS_DIR = path.join(HERE, "bindings")

with open(path.join(HERE, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


def list_dir(_dir, sort=True):
    """List directory"""

    dirs = listdir(_dir)

    if sort:
        dirs.sort()

    return dirs


PACKAGES = []
PACKAGE_DIR = {}
PACKAGE_DATA = {}

for package in list_dir(BINDINGS_DIR):
    if package.endswith(".egg-info"):
        continue

    if path.isfile(path.join(BINDINGS_DIR, package)):
        continue

    PACKAGES.append(package)
    PACKAGE_DIR[package] = "bindings/{}".format(package)
    PACKAGE_DATA[package] = ["*.pyi", "py.typed"]

# https://setuptools.pypa.io/en/latest/userguide/declarative_config.html
setup(
    name=__name__,
    version=__version__,
    url=__repo__,
    author=__author__,
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Embedded Systems",
        "Topic :: System :: Hardware",
        "Typing :: Typed",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    license="GNU General Public License v3 (GPLv3)",
    description="Type support (typings) for CircuitPython built-in binding packages.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=["circuitpython", "micropython", "adafruit"],
    python_requires=">=3.7.0",
    install_requires=["adafruit-circuitpython-typing"],
    packages=PACKAGES,
    package_dir=PACKAGE_DIR,
    package_data=PACKAGE_DATA,
)



"""Functions to manage environment variables from a .env file.

   A subset of the CPython `dotenv library <https://saurabh-kumar.com/python-dotenv/>`_. It does
   not support variables or double quotes.

   The simplest way to define keys and values is to put them in single quotes. \ and ' are
   escaped by \ in single quotes. Newlines can occur in quotes for multiline values. Comments
   start with # and apply for the rest of the line.

   File format example:

   .. code-block::

       key=value
         key2 = value2
       'key3' = 'value with spaces'
       # comment
       key4 = value3 # comment 2
       'key5'=value4
       key=value5 # overrides the first one
       multiline = 'hello
       world
       how are you?'

"""

from __future__ import annotations

import typing
from typing import Optional

def get_key(dotenv_path: str, key_to_get: str) -> Optional[str]:
    """Get the value for the given key from the given .env file. If the key occurs multiple
    times in the file, then the last value will be returned.

    Returns None if the key isn't found or doesn't have a value."""
    ...

def load_dotenv() -> None:
    """Does nothing in CircuitPython because os.getenv will automatically read .env when
    available.

    Present in CircuitPython so CPython-compatible code can use it without error."""
    ...
